# Validating the Plan Lifecycle Phase
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/validating-plan-lifecycle-phase#overview)
  * [Configuration](https://help.sap.com/docs/leanix/ea/validating-plan-lifecycle-phase#configuration)
  * [Script](https://help.sap.com/docs/leanix/ea/validating-plan-lifecycle-phase#script)


Configure an automation with a script to validate the Plan lifecycle phase on fact sheets and adjust it if needed.
